@@ -1,4 +1,5 @@
 import os
+import sys
 import json
 import click
 import subprocess
@@ -18,6 +19,7 @@ class Network3Medusa():
 
     def network3_medusa(self):
         self.py2output()
+        print(sys.getsizeof(self.output))
         raw_json=self.output.stdout.decode('utf-8')
         if 'eth_admin_fec_state' in raw_json:
             json_dict = json.loads(raw_json)
@@ -45,9 +47,7 @@ class Network3Medusa():
                 self.send_webex_notification()
         
     def py2output(self):
-        print("calling python2")
         self.output = subprocess.run(["python", "call_cli.py", self.command], capture_output=True)
-        print(self.output)
 
     def add_file_to_hedera(self, raw_json):
         self.client = Client.forTestnet()
